@@ -25,7 +25,7 @@ CsparseMatrix <- function(dim, i, j, nzdata, dimnames=NULL)
                         'integer'=, 'double'="dgCMatrix",
                         'logical'="lgCMatrix",
                         stop(wmsg("unsupported data type: ", nzdata_type)))
-    dimnames <- normarg_dimnames(dimnames, dim)
+    dimnames <- S4Arrays:::normarg_dimnames(dimnames, dim)
     oo <- order(j, i)
     ans_i <- i[oo] - 1L  # dgCMatrix and lgCMatrix objects want this zero-based
     ans_p <- c(0L, cumsum(tabulate(j[oo], nbins=dim[[2L]])))
@@ -49,7 +49,7 @@ RsparseMatrix <- function(dim, i, j, nzdata, dimnames=NULL)
                         'integer'=, 'double'="dgRMatrix",
                         'logical'="lgRMatrix",
                         stop(wmsg("unsupported data type: ", nzdata_type)))
-    dimnames <- normarg_dimnames(dimnames, dim)
+    dimnames <- S4Arrays:::normarg_dimnames(dimnames, dim)
     oo <- order(i, j)
     ans_j <- j[oo] - 1L  # dgRMatrix and lgRMatrix objects want this zero-based
     ans_p <- c(0L, cumsum(tabulate(i[oo], nbins=dim[[1L]])))
@@ -64,27 +64,10 @@ RsparseMatrix <- function(dim, i, j, nzdata, dimnames=NULL)
 ### rowsum() and colsum() methods
 ###
 
-compute_ugroup <- function(group, expected_group_len, reorder=TRUE)
-{
-    if (!(is.vector(group) || is.factor(group)))
-        stop(wmsg("'group' must be a vector or factor"))
-    if (length(group) != expected_group_len)
-        stop(wmsg("incorrect length for 'group'"))
-    if (!isTRUEorFALSE(reorder))
-        stop(wmsg("'reorder' must be TRUE or FALSE"))
-    ## Taken from base::rowsum.default().
-    ugroup <- unique(group)
-    if (anyNA(ugroup))
-        warning(wmsg("missing values for 'group'"))
-    if (reorder)
-        ugroup <- sort(ugroup, na.last=TRUE, method="quick")
-    ugroup
-}
-
 .rowsum_dgCMatrix <- function(x, group, reorder=TRUE, na.rm=FALSE)
 {
     stopifnot(is(x, "dgCMatrix"))
-    ugroup <- compute_ugroup(group, nrow(x), reorder)
+    ugroup <- S4Arrays:::compute_ugroup(group, nrow(x), reorder)
     if (!isTRUEorFALSE(na.rm))
         stop(wmsg("'na.rm' must be TRUE or FALSE"))
     group <- match(group, ugroup)
@@ -94,21 +77,6 @@ compute_ugroup <- function(group, expected_group_len, reorder=TRUE)
     ans
 }
 
-### The base package provides rowsum() only (as an S3 generic).
-setGeneric("rowsum", signature="x")
-
-setGeneric("colsum", signature="x",
-    function(x, group, reorder=TRUE, ...)
-        standardGeneric("colsum")
-)
-
-setMethod("colsum", "ANY",
-    function(x, group, reorder=TRUE, ...)
-    {
-        t(rowsum(t(x), group, reorder=reorder, ...))
-    }
-)
-
 ### S3/S4 combo for rowsum.dgCMatrix
 rowsum.dgCMatrix <- function(x, group, reorder=TRUE, ...)
     .rowsum_dgCMatrix(x, group, reorder=reorder, ...)
